@@ -23,10 +23,10 @@ elastic_vars = {
     "__user__": "elastic",
     "__password__": "uZCxWGE35lD3lhc",
     "__es__": Elasticsearch(
-        host="45.56.113.162:9200",
-        
-        user= "elastic",
-        password="uZCxWGE35lD3lhc"
+        ["45.56.113.162:9200"],
+        http_auth=("elastic",
+                   "uZCxWGE35lD3lhc"),
+        timeout=60
         )
     
 }
@@ -156,34 +156,59 @@ def last_n(n=1):
     sql_vars["__cursor__"].execute("SELECT *, month(date) as month FROM news ORDER BY ID DESC LIMIT ?" , (n,))
     return pd.DataFrame(sql_vars["__cursor__"].fetchall(), columns=columns)
 
-def get_dataset(keyword, country, from_, to_):
+def get_dataset(country, from_, to_, keyword=None):
     global elastic_vars
-    query = {
-        "query": { 
-            "bool": {
-                "must": [{
-                    "match": {
-                        "text":keyword
-                        }
-                    }],
-                "filter":[
-                    {"range":{
-                        "date":{
-                            "gte": from_,
-                            "lt": to_
+    if keyword!=None:
+        query = {
+            "query": { 
+                "bool": {
+                    "must": [{
+                        "match": {
+                            "text":keyword
+                            }
+                        }],
+                    "filter":[
+                        {"range":{
+                            "date":{
+                                "gte": from_,
+                                "lt": to_
+                                }
+                            }
+                        },
+                        {"term":{
+                            "country": country
                             }
                         }
-                    },
-                    {"term":{
-                        "country": country
+                        ]
+                    }
+                }
+            }
+    else:
+        query = {
+            "query": { 
+                "bool": {
+                    "filter":[
+                        {"range":{
+                            "date":{
+                                "gte": from_,
+                                "lt": to_
+                                }
+                            }
+                        },
+                        {"term":{
+                            "country": country
+                            }
                         }
+                        ]
                     }
-                    ]
                 }
             }
-        }
     res = elastic_vars["__es__"].search(index="news", body=query, size=10000)
-    print("Son %d noticias encontradas..." % res['hits']['total']['value'])
+    n_news = res['hits']['total']['value']
+    if n_news == 10000:
+        print("Se encontraron mas de %d noticias, por favor acotar la fecha de busqueda" % n_news)
+    else:
+        print("Son %d noticias encontradas..." % n_news)
     
     data = {'id_news':[],'country':[],'media_outlet':[],'url':[],'title':[],'text':[],'date':[],'search':[]}
     df = pd.DataFrame(data)
